@@ -1,9 +1,8 @@
 """
 Map class.
 
-@author: Gautham Ganapathy
-@organization: LEMS (http://neuroml.org/lems/, https://github.com/organizations/LEMS)
-@contact: gautham@lisphacker.org
+:author: Gautham Ganapathy
+:organization: LEMS (https://github.com/organizations/LEMS)
 """
 
 from lems.base.base import LEMSBase
@@ -26,7 +25,5 @@ class Map(dict, LEMSBase):
         """
         Returns an iterator.
         """
-        #print("Returning iter on %s"%self)
-        values = self.values()
-        #print("Returning vals: %s"%values)
-        return iter(values)
+        
+        return iter(self.values())
