@@ -1,9 +1,8 @@
 """
 Command line simulation driver.
 
-@author: Gautham Ganapathy
-@organization: LEMS (http://neuroml.org/lems/, https://github.com/organizations/LEMS)
-@contact: gautham@lisphacker.org
+:author: Gautham Ganapathy
+:organization: LEMS (https://github.com/organizations/LEMS)
 """
 
 import argparse
@@ -13,44 +12,9 @@ from lems.sim.build import SimulationBuilder
 from lems.model.simulation import DataDisplay,DataWriter
 
 
-from lems.parser.expr import ExprParser as EP
-
 dlems_info = "dLEMS (distilled LEMS in JSON format, see https://github.com/borismarin/som-codegen)"
-
-def printsexp(sexp, prefix = '', indent = '||'):
-    s = sexp
-    i = 0
-    l = len(s)
-
-    print('')
-    print(prefix,)
     
-    while i < l:
-        if s[i] == '(':
-            s = printsexp(s[(i + 1):], prefix + indent, indent)
-            i = 0
-            l = len(s)
-        elif s[i] == ')':
-            #print('')
-            return s[(i + 1):]
-        elif s[i] == ' ':
-            print('')
-            print(prefix,)
-            i = i + 1
-        else:
-            print(s[i],)
-            i = i + 1
 
-    return ''
-    
-def main2():
-    #expr = 'x'
-    #expr = '( (V - ((V^3) / 3)) - W + I) / SEC'
-    expr = '(V - (V^3) / 3 - W + I) / SEC'
-    sexp = str(EP(expr).parse())
-    print(sexp)
-    printsexp(sexp)
-    
 def process_args():
     """ 
     Parse command-line arguments.
@@ -75,14 +39,27 @@ def process_args():
                         help="If this is specified, export the LEMS file as "+dlems_info)
     
     return parser.parse_args()
-    
-def main():
+
+def run(file_path,include_dirs=[],dlems=False,nogui=False):
+    """
+    Function for running from a script or shell.
+    """
+    import argparse
+    args = argparse.Namespace()
+    args.lems_file = file_path
+    args.I = include_dirs
+    args.dlems = dlems
+    args.nogui = nogui
+    main(args=args)
+
+def main(args=None):
     """
     Program entry point.
     """
     
-    args = process_args()
-
+    if args is None:
+        args = process_args()
+    
     print('Parsing and resolving model: '+args.lems_file)
     model = Model()
     if args.I is not None:
@@ -128,13 +105,11 @@ def main():
     else:
         print('Running simulation')
         sim.run()
-
-        process_simulation_output(sim, args)
-    
+        process_simulation_output(sim, model, args)
     
 fig_count = 0
 
-def process_simulation_output(sim, options):
+def process_simulation_output(sim, model, options):
     global fig_count
 
     print('Processing results')
@@ -144,6 +119,23 @@ def process_simulation_output(sim, options):
 
     file_times = {}
     file_outs = {}
+    
+    display_order = {}
+    file_column_order = {}
+    
+    simulation = model.components[model.targets[0]]
+    for c in simulation.children:
+        if c.type == 'Display':
+            display_order[c.parameters['title']] = []
+            for l in c.children:
+                display_order[c.parameters['title']].append(l.parameters['quantity'])
+                
+        if c.type == 'OutputFile':
+            file_column_order[c.parameters['fileName']] = []
+            for f in c.children:
+                file_column_order[c.parameters['fileName']].append(f.parameters['quantity'])
+                
+    recordings = {}
 
     while rq != []:
         runnable = rq[0]
@@ -156,8 +148,12 @@ def process_simulation_output(sim, options):
         if runnable.recorded_variables:
             for recording in runnable.recorded_variables:
                 if isinstance(recording.data_output, DataDisplay):
+                    data_output = recording.data_output
                     if not options.nogui:
-                        plot_recording(recording)
+                        if data_output.title not in recordings:
+                            recordings[data_output.title] = {}
+                            
+                        recordings[data_output.title][recording.full_path] = recording
                 elif isinstance(recording.data_output, DataWriter):
                     data_output = recording.data_output
                     times = []
@@ -167,25 +163,39 @@ def process_simulation_output(sim, options):
                         vals.append(y)
                     file_times[data_output.file_name] = times
                     if data_output.file_name not in file_outs:
-                        file_outs[data_output.file_name] = []
-                    file_outs[data_output.file_name].append(vals)
+                        file_outs[data_output.file_name] = {}
+                
+                    file_outs[data_output.file_name][recording.full_path] = vals
                 else:
                     raise Exception("Invalid output type - " + str(type(recording.data_output)))
 
-    for file_out_name in file_times.keys():
+    
+    
+    for file_out_name in file_column_order.keys():
         times = file_times[file_out_name]
         vals = file_outs[file_out_name]
-        print('Going to save {0}x{1} data points to file {2}'.format(len(times),len(vals),file_out_name))
-        file_out = open(data_output.file_name, 'w')
+        print('Going to save {0}x{1} data points to file {2}'.format(len(times),len(vals.keys()),file_out_name))
+        file_out = open(file_out_name, 'w')
         i=0
         
         for time in times:
-           file_out.write('{0}   '.format(time))
-           for val in vals:
+            file_out.write('{0}   '.format(time))
+            columns = file_column_order[file_out_name]
+            for column in columns:
+                val = vals[column]
                 file_out.write('{0}   '.format(val[i]))
-           file_out.write('\n')
-           i += 1
+                
+            file_out.write('\n')
+            i += 1
+            
+        file_out.close()
 
+    if not options.nogui:
+        for display in display_order.keys():
+            lines = display_order[display]
+            recordings_here = recordings[display]
+            for line in lines:
+                plot_recording(recordings_here[line])
 
     if fig_count > 0:
         import matplotlib.pyplot as pylab
